//
//  LiveApi.swift
//  SodaLive
//
//  Created by klaus on 2023/08/09.
//

import Foundation
import Moya

enum LiveApi {
    case roomList(request: GetRoomListRequest)
    case recentVisitRoomUsers
}

extension LiveApi: TargetType {
    var baseURL: URL {
        return URL(string: BASE_URL)!
    }
    
    var path: String {
        switch self {
        case .roomList:
            return "/live/room"
            
        case .recentVisitRoomUsers:
            return "/live/room/recent_visit_room/users"
        }
    }
    
    var method: Moya.Method {
        switch self {
        case .roomList, .recentVisitRoomUsers:
            return .get
        }
    }
    
    var task: Moya.Task {
        switch self {
        case .roomList(let request):
            var parameters = [
                "timezone": request.timezone,
                "status": request.status.rawValue,
                "page": request.page - 1,
                "size": request.size,
            ] as [String : Any]
            
            if let dateString = request.dateString {
                parameters["dateString"] = dateString
            }
            
            return .requestParameters(
                parameters: parameters,
                encoding: URLEncoding.queryString)
            
        case .recentVisitRoomUsers:
            return .requestPlain
        }
    }
    
    var headers: [String : String]? {
        return ["Authorization": "Bearer \(UserDefaults.string(forKey: UserDefaultsKey.token))"]
    }
}
